@@ -32,6 +32,7 @@
 #include <qvaluevector.h>
 #include <qdatetime.h>
 #include "ctrackinf.h"
+#include "csourceformat.h"
 #include "cecaiacontroller.h"
 
 /*-------------------------------------------------------------------------*/
@@ -69,6 +70,14 @@ public:
   //! \brief  ꤵƤϤο֤
   //! \return Ϥο
   int numberOfOutputs();
+  //! \brief  Ͽ֤
+  CSourceFormat soundSourceFormat() const;
+  //! \brief  Хåե֤
+  int bufferSize() const;
+  //! \brief  Ͽꤹ롣
+  void setSoundSourceFormat(const CSourceFormat& format);
+  //! \brief  Хåեꤹ롣
+  void setBufferSize(int nSize);
 
 public slots:
   //! \brief 󥻥åȥåפ򿷵롣
@@ -163,6 +172,10 @@ private:
   QStringList strlTmpFiles;
   //! Ծ
   RunningStatus rStatus;
+  //! Ͽեޥå
+  CSourceFormat formatRecording;
+  //! Хåե
+  int           nBufferSize;
 
   //! \brief ȥå̾ΤФȥåΥǥ֤
   //! ꤵ줿ȥå̾ΤФȥå󤬸Ĥʤ硢
