@@ -445,7 +445,7 @@ WVoxBase::setupWidgets()
   //  Tab->addTab(TextEditCmdLine, "Commandline");
   TextEditEcasound = new KTextEdit(Tab);
   TextEditEcasound->setReadOnly(true);
-  Tab->addTab(TextEditEcasound, "Ecasound console");
+  Tab->addTab(TextEditEcasound, i18n("Ecasound console"));
 }
 
 /////////////////////////////////////////////////////////////////////////////
