@@ -162,8 +162,13 @@ WVoxStorm::readConfigurationFile()
   preferences.strProjectPath = Config->readEntry("ProjectPath", "~/voxstorm");
 
   Config->setGroup("Sound Spec");
-  preferences.uiSampleRate = Config->readNumEntry("SamplingRate", 44100);
-  preferences.uiBuffer     = Config->readNumEntry("BufferSize", 256);
+  preferences.format.setSampleFormat(
+    CSourceFormat::sampleFormatIdentifier(
+      Config->readEntry("SamplingFormat", "se16_le")));
+  preferences.format.setChannelCount(Config->readNumEntry("Channels", 2));
+  
+  preferences.format.setSampleRate(Config->readNumEntry("SamplingRate", 44100));
+  preferences.uiBuffer     = Config->readNumEntry("BufferSize", 1024);
 
   Config->setGroup("Track");
   Config->readListEntry("DefaultTracks", strListTmp, ',');
@@ -213,7 +218,11 @@ WVoxStorm::writeConfigurationFile()
   Config->writeEntry("ProjectPath", preferences.strProjectPath);
 
   Config->setGroup("Sound Spec");
-  Config->writeEntry("SamplingRate", preferences.uiSampleRate);
+  Config->writeEntry(
+    "SamplingFormat", 
+    CSourceFormat::sampleFormatString(preferences.format.sampleFormat()));
+  Config->writeEntry("Channels", preferences.format.channelCount());
+  Config->writeEntry("SamplingRate", preferences.format.sampleRate());
   Config->writeEntry("BufferSize", preferences.uiBuffer);
 
   QStrList  strListTmp;
@@ -250,6 +259,8 @@ WVoxStorm::writeConfigurationFile()
 void 
 WVoxStorm::applyPreferences()
 {
+  EcaIAManager.setBufferSize(preferences.uiBuffer);
+  EcaIAManager.setSoundSourceFormat(preferences.format);
   VoxBase->setMaxSessionLength(preferences.timeSessionMax);
 }
 
@@ -515,7 +526,7 @@ WVoxStorm::maybeSave()
 QString
 WVoxStorm::sessionName() const
 {
-  if ( strSessionFile == "" ) {
+  if ( strSessionFile.isEmpty() ) {
     return kapp->caption();
   }
 
@@ -719,7 +730,7 @@ WVoxStorm::slotOpen()
 bool 
 WVoxStorm::slotSave()
 {
-  if ( strSessionFile == "" ) {
+  if ( strSessionFile.isEmpty() ) {
     return slotSaveAs();
   } else {
     saveFile(strSessionFile);
@@ -740,7 +751,7 @@ WVoxStorm::slotSaveAs()
                      true);
   dialog.exec();
   QString strFileName = dialog.selectedFile();
-  if ( strFileName == "" ) {
+  if ( strFileName.isEmpty() ) {
     return false;
   }
 
@@ -932,7 +943,7 @@ WVoxStorm::slotRunMixer()
   KShellProcess process;
 
   process << preferences.strMixerPath;
-  bool bStat = process.start(KProcess::DontCare);
+  process.start(KProcess::DontCare);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -1025,7 +1036,7 @@ WVoxStorm::slotRemoveTrack(const QString& strTrackName)
 /////////////////////////////////////////////////////////////////////////////
 
 void
-WVoxStorm::slotChangeFileName(const QString& strTrackName, const QString& strFileName)
+WVoxStorm::slotChangeFileName(const QString& strTrackName, const QString&)
 {
   if ( ToggleActionInteractive->isChecked() ) {
     if ( !EcaIAManager.isExisting(strTrackName) ) {
