@@ -330,9 +330,9 @@ WVoxTrack::stateInTrackInf() const
   trackInfReturn.strOutputDevice = strOutputDevice;
   trackInfReturn.nLevel          = IntNumInputLevel->value();
   trackInfReturn.nPan            = IntNumInputPan->value();
-  trackInfReturn.TimeStartPosition  = timeStartPosition;
-  trackInfReturn.TimeOffset      = timeOffset;
-  trackInfReturn.TimeLength      = timeLength;
+  trackInfReturn.timeStartPosition  = timeStartPosition;
+  trackInfReturn.timeOffset      = timeOffset;
+  trackInfReturn.timeLength      = timeLength;
   trackInfReturn.bMute           = PushButtonMute->isOn();
   trackInfReturn.bRecPort        = PushButtonRec->isOn();
 
@@ -486,9 +486,9 @@ WVoxTrack::setStateByTrackInf(const CTrackInf& trackInfSet)
   strOutputDevice = trackInfSet.strOutputDevice;
   IntNumInputLevel->setValue(trackInfSet.nLevel);
   IntNumInputPan->setValue(trackInfSet.nPan);
-  timeStartPosition = trackInfSet.TimeStartPosition;
-  timeOffset        = trackInfSet.TimeOffset;
-  timeLength        = trackInfSet.TimeLength;
+  timeStartPosition = trackInfSet.timeStartPosition;
+  timeOffset        = trackInfSet.timeOffset;
+  timeLength        = trackInfSet.timeLength;
   PushButtonMute->setOn(trackInfSet.bMute);
   PushButtonRec->setOn(trackInfSet.bRecPort);
 }
