@@ -61,25 +61,31 @@ public:
   //! \param strName ȥå̾Ρ
   //! \param strDeviceIn ϥǥХ
   //! \param strDeviceOut ϥǥХ
+  //! \param timeMaxSession åĹ
   //! \param WidgetParent ƥåȤؤΥݥ󥿡
   //! \param cName åȤ̾Ρ
   WVoxTrack(const QString& strName,
             const QString& strDeviceIn,
             const QString& strDeviceOut,
+            const QTime&   timeMaxSession, 
             QWidget*       WidgetParent=0,
             const char*    cName=0);
   //! \brief 󥹥ȥ饯
   //! \param trackInf ȥå
+  //! \param timeMaxSession åĹ
   //! \param WidgetParent ƥåȤؤΥݥ󥿡
   //! \param cName å̾Ρ
   WVoxTrack(const CTrackInf& trackInf, 
+            const QTime&     timeMaxSession, 
             QWidget*         WidgetParent=0,
             const char*      cName=0);
   //! \brief 󥹥ȥ饯
   //! \param nodTrack DOMΡɡ
+  //! \param timeMaxSession åĹ
   //! \param WidgetParent ƥåȡ
   //! \param cName åȤ̾Ρ
   WVoxTrack(const QDomNode& nodTrack,
+            const QTime&    timeMaxSession, 
             QWidget*        WidgetParent=0, 
             const char*     cName=0);
   //! \brief ǥȥ饯
@@ -143,6 +149,9 @@ public:
   //! \param  nodTrack DOMΡɡ
   void      setStateByDom(const QDomNode& nodTrack);
 
+  //! \brief  ȥåκĹꤹ롣
+  void      setMaxSessionLength(const QTime& time);
+
   //! \brief  ȥå򥹥뤹롣
   //! \param  x Xɸ
   void      scrollLocator(int x);
@@ -226,10 +235,11 @@ private:
   //! ˥塼ID()
   int            nMenuIDLength;
 
-  //! åȤꡣ
+  //! \brief åȤꡣ
   //! 󥹥ȥ饯Τ߸ƤӽФġ
-  void setupWidgets();
-  //! ݥåץåץ˥塼ꡣ
+  //! åĹ
+  void setupWidgets(const QTime& timeMaxSession);
+  //! \brief ݥåץåץ˥塼ꡣ
   //! 󥹥ȥ饯Τ߸ƤӽФġ
   void setupPopupMenu();
 
